<?php

namespace Concrete\Package\AbSpacer\Block\AbSpacer;

/**
 * ab_spacer package for Concrete5
 * Copyright Copyright 2017-2018, Alex Borisov
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @author Alex Borisov <linuxoidoz@gmail.com>
 * @package Concrete\Package\ab_spacer
 */
 
class Controller extends \Concrete\Core\Block\BlockController
{
    
    protected $btWrapperClass = 'ccm-ui';
    protected $btInterfaceWidth = "600";
    protected $btInterfaceHeight = "400";
    protected $btTable = 'btAbSpacer';
    protected $btDefaultSet = 'basic';
    
    public function getBlockTypeDescription() 
    {
        return t("Add Block Spacer block");
    }

    public function getBlockTypeName() 
    {
        return t("Block Spacer");
    }

    public function on_start() {
        $this->set('app', $this->app);
    }
    
    public function view() 
    {
        $this->set('show_line', $this->show_line);
        $this->set('show_picture', $this->show_picture);
        $this->set('show_note', $this->show_note);
        $this->set('pic', $this->getPictureObject());
        $this->set('note', $this->note);
        $this->set('size', $this->size);
        $this->set('style', $this->style);
        $this->set('color', $this->color);
        $this->set('height', $this->height);
    }

    public function add()
    {
        $this->set('pic', null);
        
        $border_styles = array(
            'none' => 'none',
            'solid' => 'solid',
            'dotted' => 'dotted',
            'dashed' => 'dashed',
            'double' => 'double',
            'groove' => 'groove',
            'ridge' => 'ridge',
            'inset' => 'inset',
            'outset' => 'outset'
        );
        $this->set('border_styles', $border_styles);
    }

    public function edit()
    {
        $pic = null;
        if ($this->getPictureID() > 0) {
            $pic = $this->getPictureObject();
        }
        $this->set('pic', $pic);
        
        $border_styles = array(
            'none' => 'none',
            'solid' => 'solid',
            'dotted' => 'dotted',
            'dashed' => 'dashed',
            'double' => 'double',
            'groove' => 'groove',
            'ridge' => 'ridge',
            'inset' => 'inset',
            'outset' => 'outset'
        );
        $this->set('border_styles', $border_styles);
    }
    
    public function save($args) 
    {
        $args['note'] = isset($args['note']) ? $args['note'] : '';
        $args['size'] = isset($args['size']) ? $args['size'] : '1';
        $args['style'] = isset($args['style']) ? $args['style'] : 'solid';
        $args['color'] = isset($args['color']) ? $args['color'] : '#666666';
        $args['height'] = isset($args['height']) ? $args['height'] : '40';
        $args['pictureID'] = (isset($args['show_picture']) && $args['pictureID'] != 0) ? $args['pictureID'] : 0;
        $args['show_line'] = isset($args['show_line']) ? 1 : 0;
        $args['show_picture'] = (isset($args['show_picture']) && $args['pictureID'] != 0) ? 1 : 0;
        $args['show_note'] = isset($args['show_note']) ? 1 : 0;
        parent::save($args);
    }

    public function getPictureID()
    {
        return isset($this->record->pictureID) ? $this->record->pictureID : (isset($this->pictureID) ? $this->pictureID : null);
    }

    public function getPictureObject()
    {
        return \Concrete\Core\File\File::getByID($this->getPictureID());
    }

    public function validate($args)
    {
        $e = $this->app->make('helper/validation/error');
        $height = trim($args['height']);
        if (!filter_var($height, FILTER_VALIDATE_INT) || (int)$height < 1) {
            $e->add(t('Height must be integer and > 0'));
        }
        
        return $e;
    }
     
}
